import React from "react";
import './App.css';
import {
  Redirect,
  Route,
  BrowserRouter as Router,
  Switch,
} from 'react-router-dom';
import { ThemeProvider } from "@material-ui/core/styles"
import { CssBaseline } from "@material-ui/core";
import { theme } from "./Theme";
import { IOCListView } from './views/IOC/IOCListView';
import { GlobalAppBar } from './components/navigation/GlobalAppBar/GlobalAppBar';
import { IOCDetailsView } from './views/IOC/IOCDetailsView';
import { DeploymentsView } from './views/deployments/DeploymentsView'
import { DeploymentDetailsView } from './views/deployments/DeploymentDetailsView'
import { APIProvider, UserProvider } from './api/SwaggerApi';
import ProtectedRoute from "./components/auth/ProtectedRoute";
import { LoginView } from "./views/User/LoginView";
import { HostListView } from "./views/host/HostListView";
import { HostDetailsView } from "./views/host/HostDetailsView";
import { SnackbarProvider } from 'notistack';

function App() {

  return (
    <SnackbarProvider preventDuplicate>
      <ThemeProvider theme={theme}>
        <CssBaseline />
        <Router>
          <APIProvider >
            <UserProvider>
              <Switch>
                <Route exact path="/login">
                  <LoginView />
                </Route>
                <Route path="/"
                  render={({ match }) => {
                    console.log(match)
                    return (
                      <ProtectedRoute>
                        <GlobalAppBar>
                          <Switch>
                            <Route exact path="/">
                              <Redirect to="/iocs" />
                            </Route>
                            <Route path="/iocs/:id" component={IOCDetailsView} />
                            <Route path="/iocs" component={IOCListView} />
                            <Route path="/deployments/:id" component={DeploymentDetailsView} />
                            <Route path="/deployments" component={DeploymentsView} />
                            <Route path="/hosts/:id" component={HostDetailsView} />
                            <Route path="/hosts" component={HostListView} />
                            <Route>
                              <NotFound404 />
                            </Route>
                          </Switch>
                        </GlobalAppBar>
                      </ProtectedRoute>
                    )
                  }
                  }
                />
                <Route>
                  <NotFound404 />
                </Route>
              </Switch>
            </UserProvider>
          </APIProvider>
        </Router>
      </ThemeProvider>
    </SnackbarProvider>
  );
}

function NotFound404() {
  return (
    <div>
      <h1>404 - Not Found!</h1>
    </div>
  );
}

export default App;
