import { Container, Fab, IconButton, useTheme } from "@material-ui/core";
import { DirectionsBoat, Edit } from "@material-ui/icons";
import React, { useState } from "react";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { IOCDetails } from "../../components/IOC/IOCDetails";
import { CreateIOC } from "../../components/IOC/CreateIOC";
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";
import { useUpdateIOC } from "../../api/SwaggerApi";
import { Alert } from "@material-ui/lab";

export function IOCConfiguration({ ioc, getIOC, deployment, createDeployment }) {
  const [iocFormOpen, setIOCFormOpen] = useState(false);
  const theme = useTheme();
  console.log(deployment);

  useGlobalAppBar(
    "IOC Details",
    <IconButton onClick={() => { setIOCFormOpen(true) }}>
      <Edit style={{ fill: theme.palette.primary.contrastText }} />
    </IconButton>
  );

  const closeModal = () => {
    setIOCFormOpen(false);
    getIOC();
    // history.push(window.location.pathname);
  }

  let content = <></>;
  if (ioc) {
    console.log({ ...ioc });
    const undeployedChanges = (ioc.latestVersion.sourceUrl !== ioc.deployedVersion?.sourceUrl) ||
      (ioc.latestVersion.sourceVersion !== ioc.deployedVersion?.sourceVersion) ||
      (ioc.latestHost?.id !== ioc.activeDeployment?.host.id);
    const alert = undeployedChanges ?
      (<Alert severity="warning" variant="standard">These changes have not been deployed yet.</Alert>)
      : (<Alert severity="success" variant="standard"><Container>This version has been deployed successfully.</Container></Alert>);

    const getSubset = (ioc) => {
      ioc = { ...ioc };
      const { name,
        description,
        // active, 
        status } = ioc;
      const { sourceVersion: version, sourceUrl: git } = ioc.latestVersion;
      const host = ioc.latestHost?.host;
      return {
        name,
        description,
        "target host": host,
        // active: (active && (ioc.latestVersion.id == ioc.deployedVersion?.id)), 
        "Target host status": status?.toLowerCase(),
        git,
        version
      };
    };

    const formInit = {
      name: ioc.name,
      description: ioc.description,
      version: ioc.latestVersion.sourceVersion,
      git: ioc.latestVersion.sourceUrl,
    };

    if (ioc.latestHost) {
      formInit.csEntryHost = {
        fqdn: ioc.latestHost.host,
        id: ioc.latestHost.csEntryId,
      }
    }

    content = (
      <>
        <IOCDetails ioc={ioc} getSubset={getSubset} alert={alert} />
        {
          (ioc && ioc.host) &&
          <Fab color={undeployedChanges ? "secondary" : "primary"} variant="extended" style={{
            position: "fixed",
            bottom: "2%",
            left: "50%",
            /* bring your own prefixes */
            transform: "translate(-50%, -50%)"
          }}
            onClick={() => { createDeployment([ioc], "triggered from a button"); getIOC(); }}>
            {(undeployedChanges) ? "DEPLOY" : "REDEPLOY"} THIS VERSION &nbsp;  <DirectionsBoat />
          </Fab>
        }
        <SimpleModal open={iocFormOpen} setOpen={setIOCFormOpen}>
          <CreateIOC submitCallback={closeModal} buttonText="Update" init={formInit} hook={useUpdateIOC.bind(null, ioc.id)} />
        </SimpleModal>
      </>
    );
  }

  return (
    <>
      {content}
    </>
  );

}