import React, { useEffect, useState } from "react";
import { Button, TextField } from "@material-ui/core";
import { Autocomplete } from "@material-ui/lab";
import { useCSEntrySearch } from "../../api/SwaggerApi";
import { useTypingTimer } from "../common/SearchBoxFilter/TypingTimer";

export function IOCForm({ submitCallback, buttonText, init = {}}) {
  // const [hosts] = useHostList();
  const [hosts, getHosts] = useCSEntrySearch();
  const [host, setHost] = useState(init.host);
  const [query, onHostKeyUp] = useTypingTimer({interval: 500});
  console.log({...init});
  console.log(hosts);
  console.log(host);

  useEffect(() => getHosts(`is_ioc:true AND fqdn:"${query}"`), [query, getHosts]);

  const onSubmit = (event) => {
    event.preventDefault();
    const { name: nameText, description: descriptionText, git: gitText, version: versionText } = event.currentTarget.elements;
    const name = nameText.value;
    const description = descriptionText.value;
    const git = gitText.value;
    const version = versionText.value;
    console.log(host);
    submitCallback({ 
      customName: name, 
      description: description, 
      owner: "dummyOwner", 
      sourceUrl: git, 
      sourceVersion: version, 
      hostCSEntryId: host ? parseInt(host.csEntryHost.id) : undefined });
  };

  return (
    <form onSubmit={onSubmit}>
      <TextField autoComplete="off" required id="name" label="name" variant="outlined" defaultValue={init.name || ""} fullWidth />
      <TextField autoComplete="off" required id="description" label="description" variant="outlined" defaultValue={init.description || ""} fullWidth />
      <TextField autoComplete="off" required id="git" label="git" variant="outlined" defaultValue={init.git || ""} fullWidth />
      <TextField autoComplete="off" required id="version" label="version" variant="outlined" defaultValue={init.version || ""} fullWidth />
      {/* <TextField autoComplete="off" id = "host" label="host (optional)" variant="outlined" defaultValue={init.host || ""} fullWidth /> */}
      <Autocomplete
        autoHighlight
        id="host"
        options={hosts}
        defaultValue = { init }
        getOptionLabel={option => {console.log(option); return option?.csEntryHost?.fqdn}}
        renderInput={(params) => <TextField {...params} required label="host" variant="outlined" />}
        onChange={(event, value, reason) => setHost(value)}
        onInputChange={(event, value, reason) => {console.log("onInputChange", event, value, reason); event && onHostKeyUp(event.nativeEvent)}}
      />
      <Button variant="contained" color="primary" fullWidth type="submit">{buttonText}</Button>
    </form>
  );
}