import React from "react";
import {
  List,
  ListItem,
  Paper,
} from "@material-ui/core";
import { Link } from 'react-router-dom';
import { IOCBadge } from "./IOCBadge";
import { SearchBoxFilter } from "../common/SearchBoxFilter/SearchBoxFilter"

export function IOCListItem({ ioc }) {
  return (
    <Paper>
      <ListItem button component={Link} to={ioc.url}>
        <IOCBadge ioc={ioc} />
      </ListItem>
    </Paper>
  );
}

export function IOCList({ iocs }) {
  return (
    <List>
      {iocs && iocs.map((ioc) => {
        ioc.url=`/iocs/${ioc.id}`;
        return (
          <IOCListItem key={ioc.id} ioc={ioc} />
        );
      })}
    </List>
  );
}

export function SearchableIOCList({ iocs }) {
  const filter = (search) => {
    search = search.toLowerCase();
    return (ioc) => {
      return ioc.name.toLowerCase().includes(search) ||
        ioc.host.toLowerCase().includes(search) ||
        ioc.git.toLowerCase().includes(search) ||
        ioc.version.toLowerCase().includes(search) ||
        ioc.owner.toLowerCase().includes(search) ||
        ioc.status.toLowerCase().includes(search);
    }
  }

  const renderFilteredIOCs = (filteredIOCs) => <IOCList iocs={filteredIOCs} />;

  return (
    <SearchBoxFilter items={iocs} filter={filter} render={renderFilteredIOCs} />
  );
}