import { Button, Snackbar, Typography } from "@material-ui/core";
import { Alert } from "@material-ui/lab";
import React from "react";
import { useGlobalAppBar } from "../navigation/GlobalAppBar/GlobalAppBar";
import { IOCDetails } from "./IOCDetails";
import { Link } from 'react-router-dom';
import { useIOCService } from "../../api/SwaggerApi";
import { useSnackbar } from 'notistack';



export function IOCLiveStatus({ ioc }) {
  useGlobalAppBar(
    "IOC Details"
  );

  const liveIOC = { ...ioc };
  liveIOC.host = ioc.activeDeployment.host.host;
  const getSubset = (ioc) => {
    const { name, description, active, status, git, version } = ioc;
    const dashboard = (
      <Typography>
        <a href={`https://grafana.tn.esss.lu.se/d/5zJT23xWz/node-exporter-full?orgId=1&var-node=${liveIOC.host}`} target="_blank" rel="noreferrer">
          Open Dashboard
        </a>
      </Typography>
    );
    return ({
      name,
      description,
      "Deployed on": <Typography><Link to={`/hosts/${ioc.activeDeployment.host.csEntryId}`}>{ioc.activeDeployment.host.host}</Link></Typography>,
      "Host status": status?.toLowerCase(),
      "IOC Service Active?": active ?? "null",
      "IOC Service Controls": <IOCServiceControls ioc={ioc}/>,
      git,
      version,
      "view host status on grafana": dashboard
    })
  };
  const alert = <Alert severity="info">This is the currently deployed version</Alert>;

  return (
    <>
      <IOCDetails ioc={liveIOC} getSubset={getSubset} />
      <Snackbar open autoHideDuration={6000}>{alert}</Snackbar>
    </>
  );
}

export function IOCServiceControls({ioc}) {
  const { startIOC, stopIOC, restartIOC } = useIOCService(ioc.id);
  const { enqueueSnackbar } = useSnackbar();
  const start = async () => {
    await startIOC();
    enqueueSnackbar(`IOC ${ioc.name} started.`, {variant: "success"})
  }
  const stop = async () => {
    await stopIOC();
    enqueueSnackbar(`IOC ${ioc.name} stopped`, {variant: "success"})
  }
  const restart = async () => {
    await restartIOC();
    enqueueSnackbar(`IOC ${ioc.name} restarted`, {variant: "success"})
  }
  return (
    <>
    <Button color="secondary" variant="outlined" onClick={stop}>Stop</Button>
    <Button variant="outlined" onClick={start}>Start</Button>
    <Button color="primary" variant="outlined" onClick={restart}>Restart</Button></>
  )
}