import React from 'react';
import { CustomTable } from "../common/table/CustomTable";
import { Paper } from '@material-ui/core';
import { useHistory } from 'react-router-dom';
import { SearchBoxFilter } from '../common/SearchBoxFilter/SearchBoxFilter';
import { IOCStatusIcon } from './IOCIcons';

const columns = [
  { id: "status", label: 'Status', align: "center" },
  { id: "name", label: 'Name', },
  { id: "host", label: 'Host', },
  { id: "owner", label: "Owner" },
  { id: "git", label: 'Source Code', },
  { id: "version", label: 'Version', },
  { id: "iocStatus", label: 'IOC Status', },
  { id: "hostStatus", label: 'Host Status', },

]

function createTableRow(ioc) {
  const { id, name, git, version, host, active, status, owner } = ioc;
  const statusIcon = <IOCStatusIcon ioc={ioc} />;

  return {
    id: id,
    status: { value: status, displayed: statusIcon },
    name: { value: name, displayed: name },
    git: { value: git, displayed: git },
    version: { value: version, displayed: version },
    host: { value: host, displayed: (host || "---") },
    owner: { value: owner, displayed: owner },
    iocStatus: { value: active, displayed: active === null ? "unknown" : (active ? "active" : "inactive") },
    hostStatus: { value: status, displayed: status ? status.toLowerCase() : "unknown" },
  };
}

export function IOCTable({ iocs }) {
  const history = useHistory();

  const onRowClicked = (id) => {
    history.push(`/iocs/${id}`);
  };

  return (
    <Paper>
      <CustomTable columns={columns} rows={iocs.map(ioc => createTableRow(ioc))} handleRowClick={onRowClicked} />
    </Paper>
  );
}

export function SearchableIOCTable({ iocs }) {
  const filter = (search) => {
    search = search.toLowerCase();
    return (ioc) => {
      return ioc.name.toLowerCase().includes(search) ||
        ioc.host.toLowerCase().includes(search) ||
        ioc.git.toLowerCase().includes(search) ||
        ioc.version.toLowerCase().includes(search) ||
        ioc.owner.toLowerCase().includes(search) ||
        ioc.status.toLowerCase().includes(search);
    }
  }

  const renderFilteredIOCs = (filteredIOCs) => <IOCTable iocs={filteredIOCs} />;

  return (
    <SearchBoxFilter items={iocs} filter={filter} render={renderFilteredIOCs} />
  );
}
