import React, { useEffect, useRef, useState } from 'react';
import { Grid, Typography, Button, Card, CardContent, CardActions, Container, LinearProgress } from '@material-ui/core';
import { makeStyles, createMuiTheme } from '@material-ui/core/styles';
import { DeploymentStepper } from "./DeploymentStepper"
import { KeyValueTable } from "../common/KeyValueTable/KeyValueTable";
import { SimpleAccordion } from "../common/Accordion/SimpleAccordion";
import { useDeploymentJob } from '../../api/SwaggerApi';
import { DeploymentBadge } from './DeploymentBadge';
import { Alert } from '@material-ui/lab';
import { Link } from 'react-router-dom';

const useStyles = makeStyles({
  root: {
    width: '100%'
  },
  actions: {
    justifyContent: 'flex-end',
  },
});

export function DeploymentDetails({ deployment, getDeployment, onDeploymentStart, startButtonDisabled }) {
  const [deploymentJob, getDeploymentJob] = useDeploymentJob(deployment.awxJobId);
  const [alert, setAlert] = useState((<Alert severity="info" variant="standard">The deployment is still in progress.</Alert>));

  useEffect(() => {
    if (deployment && !(["successful", "failed"].includes(deployment.status.toLowerCase()))) {
      setTimeout(getDeploymentJob, 5000);
      setTimeout(getDeployment, 5000);
    }
    else {
      if (deployment) {
        let alert = (deployment.status.toLowerCase() === "failed") ?
          (<Alert severity="error" variant="standard">The deployment had failures.</Alert>)
          : (<Alert severity="success" variant="standard"><Container>The deployment was successful.</Container></Alert>);
        setAlert(alert);
      }
    }
  }, [deployment, getDeployment, getDeploymentJob]);

  const deploymentDetails = {
    version: deployment.version.sourceVersion,
    host: <Typography><Link to={`/hosts/${deployment.host.csEntryId}`}>{deployment.host.host}</Link></Typography>,
    repository: deployment.version.sourceUrl,
    startTime: deployment.startDate,
    duration: (new Date(deploymentJob?.job.finished ?? Date()) - new Date(deploymentJob?.job.started ?? Date())) / 1000 + " s"
  }

  const theme = createMuiTheme();
  const classes = useStyles(theme);

  return (
    <Grid container spacing={1}>
      <Grid item xs={12} md={12}>
        <SimpleAccordion defaultExpanded summary={<DeploymentBadge deployment={deployment} />}>
          <KeyValueTable obj={deploymentDetails} variant="overline" />
        </SimpleAccordion>
      </Grid>
      <Grid item xs={12} md={12}>
        <Card className={classes.root}>
          <CardContent>
            <div className={classes.stepperContainer}>
              <DeploymentStepper activeStep={["created", "pending", "running", "successful"].indexOf(deployment.status.toLowerCase())} deploymentStatus={deployment.status} />
            </div>
          </CardContent>
          {deployment.manual &&
            <CardActions className={classes.actions}>
              <Button variant="contained" color="primary" onClick={onDeploymentStart} disabled={startButtonDisabled}>
                Start deployment
              </Button>
            </CardActions>
          }
        </Card>
      </Grid>
      {alert && <Grid item xs={12}>
          {alert}
        </Grid>}
      <Grid item xs={12} md={12}>
        <SimpleAccordion summary="Deployment Job Output" defaultExpanded>
          <DeploymentJobStdOut2 deploymentJob={deploymentJob} />
        </SimpleAccordion>
      </Grid>
    </Grid>
  );
}

export function DeploymentJobStdOut2({ deploymentJob }) {
  const stdoutRef = useRef(null);
  const [firstTime, setFirstTime] = useState(true);

  if (stdoutRef.current) {
    stdoutRef.current.scrollTop = stdoutRef.current.scrollHeight;
    if (firstTime && deploymentJob?.job.started) {
      stdoutRef.current?.parentElement.scrollIntoView(false);
      setFirstTime(false);
    }
  }

  return deploymentJob?.job.started ?
    <div
      ref={stdoutRef}
      style={{
        overflow: "auto",
        minHeight: "500px",
        maxHeight: "500px",
        width: "100%",
        color: "white",
        backgroundColor: "black"
      }}
      dangerouslySetInnerHTML={{ __html: deploymentJob.stdout }}
    />
    // : <Skeleton variant="rect" width="100%" height={500} />
    : <div style={{ width: "100%" }}><LinearProgress color="primary" /></div>
}
