import React from 'react';
import PropTypes from 'prop-types';
import { makeStyles, withStyles } from '@material-ui/core/styles';
import clsx from 'clsx';
import {Stepper, Step, StepLabel, StepConnector, Hidden} from '@material-ui/core';
import PersonIcon from '@material-ui/icons/Person';
import ComputerIcon from '@material-ui/icons/Computer';
import DescriptionIcon from '@material-ui/icons/Description';
import SendIcon from '@material-ui/icons/Send';
import { theme } from "../../Theme";

const useStyles = makeStyles({
  stepper: {
      minWidth: 500,
      width: "100%",
  },
});

const useColorlibStepIconStyles = makeStyles({
  root: {
    backgroundColor: '#ccc',
    zIndex: 1,
    color: '#fff',
    width: 50,
    height: 50,
    display: 'flex',
    borderRadius: '50%',
    justifyContent: 'center',
    alignItems: 'center',
  },
  active: {
    background: theme.palette.status.progress,
    boxShadow: '0 4px 10px 0 rgba(0,0,0,.25)',
  },
  completed: {
    background: theme.palette.status.ok,
  },
  error: {
    background: theme.palette.status.fail,
  },
});

const steps = ['Creating Deployment', 'Deployment Queued ', 'Running Deployment', 'Deployment Completed'];

const ColorlibConnectorHorizontal = withStyles({
  alternativeLabel: {
    top: 22,
  },
  active: {
    '& $line': {
      background: theme.palette.status.progress,
    },
  },
  completed: {
    '& $line': {
      background: theme.palette.status.ok,
    },
  },
  line: {
    height: 3,
    border: 0,
    backgroundColor: '#eaeaf0',
    borderRadius: 1,
  },
})(StepConnector);

const ColorlibConnectorVertical = withStyles({
  alternativeLabel: {
    top: 22,
  },
  active: {
    '& $line': {
      background: theme.palette.status.progress,
    },
  },
  completed: {
    '& $line': {
      background: theme.palette.status.ok,
    },
  },
  line: {
    width: 4,
    border: 0,
    marginLeft: 11,
    backgroundColor: '#eaeaf0',
    borderRadius: 1,
  },
})(StepConnector);

function ColorlibStepIcon(props) {
  const classes = useColorlibStepIconStyles();
  const { active, completed, error } = props;

  const icons = {
    1: <PersonIcon />,
    2: <ComputerIcon />,
    3: <DescriptionIcon />,
    4: <SendIcon />,
  };

  return (
    <div
      className={clsx(classes.root, {
        [classes.active]: active,
        [classes.completed]: completed,
        [classes.error]: error,
      })}
    >
      {icons[String(props.icon)]}
    </div>
  );
}

ColorlibStepIcon.propTypes = {
  /**
   * Whether this step is active.
   */
  active: PropTypes.bool,
  /**
   * Mark the step as completed. Is passed to child components.
   */
  completed: PropTypes.bool,
  /**
   * The label displayed in the step icon.
   */
  icon: PropTypes.node,
};

export function DeploymentStepper(props) {
  const classes = useStyles(theme);
  let {activeStep, deploymentStatus} = props;
  const isStepFailed = (step) => {
    if (deploymentStatus === "FAILED") {
      return step === activeStep+1;
    }
    return false;
  };

  console.log(activeStep);
  activeStep = activeStep<1 ? 1 : activeStep;
  activeStep = activeStep===3 ? 4 : activeStep;

  return (
    <>
      <Hidden smUp>
        <Stepper className={classes.stepper} activeStep={activeStep}  orientation="vertical" connector={<ColorlibConnectorVertical />}>
          {steps.map((label, index) => {
            const labelProps = {};
            const stepProps = {};
            if (isStepFailed(index)) {
              labelProps.error = true;
              stepProps.error = true;
            }

            return (
            <Step key={label}>
              <StepLabel {...labelProps} StepIconComponent={ColorlibStepIcon}>{label}</StepLabel>
            </Step>
        )})}
      </Stepper>
      </Hidden>
      <Hidden xsDown>
        <Stepper className={classes.stepper} alternativeLabel activeStep={activeStep} connector={<ColorlibConnectorHorizontal />}>
          {steps.map((label, index) => {
            const labelProps = {};
            const stepProps = {};
            if (isStepFailed(index)) {
              labelProps.error = true;
              stepProps.error = true;
            }

            return (
            <Step key={label} {...stepProps}>
              <StepLabel {...labelProps} StepIconComponent={ColorlibStepIcon}>{label}</StepLabel>
            </Step>
          )})}
        </Stepper>
      </Hidden>
    </>
  );
}