import React from 'react';
import { CustomTable } from "../common/table/CustomTable";
import { CheckCircleOutline, ErrorOutline, RotateRightOutlined, ScheduleOutlined } from "@material-ui/icons";
import { SearchBoxFilter } from "../common/SearchBoxFilter/SearchBoxFilter";
import { theme } from "../../Theme";
import { DeploymentStatusIcon } from './DeploymentIcons';
import { useHistory } from 'react-router';

const columns = [
  { id: 'status', label: 'Deployment Status', align: 'center', comparator:  statusDescComparator},
  { id: 'ioc', label: 'IOC Name' },
  { id: 'version', label: 'Version' },
  { id: 'host', label: 'Host' },
  { id: 'user', label: 'User' },
  { id: 'comment', label: 'Comment' },
  { id: 'start', label: 'Start date', format: (value) => value ? value.toLocaleString() : "Queued" },
  // { id: 'duration', label: 'Duration', align: 'right', format: (value) => value > 60 ? (Math.floor(value / 60) + " m " + value % 60 + " s") : value + " s" }
];

function statusDescComparator(a, b) {
  const statusOrder = {
    "success": 3,
    "failed": 2,
    "running": 0,
    "scheduled": 1};

    if (statusOrder[b.status.value] < statusOrder[a.status.value]) {
        return -1;
    }
    if (statusOrder[b.status.value] > statusOrder[a.status.value]) {
        return 1;
    }
    
    return 0;
}

function createTableRow(deployment) {
  console.log(deployment);
  // const iconStyle = { fill: deploymentStatusColors[deployment.status] };
  // const statusIcon = React.cloneElement(deploymentStatusIcons[deployment.status], { style: iconStyle });
  return { 
    id:deployment.id, 
    status: {value: deployment.status, displayed: <DeploymentStatusIcon deployment={deployment}/>},
    ioc: {value: deployment.iocName, displayed: deployment.iocName},
    version: {value: deployment.version.sourceVersion, displayed: deployment.version.sourceVersion}, 
    host: {value: deployment.host ? deployment.host.host : null, displayed: deployment.host ? deployment.host.host : null}, 
    user: {value: deployment.createdBy, displayed: deployment.createdBy}, 
    comment: {value: deployment.comment, displayed: deployment.comment},
    start: {value: deployment.startDate, displayed: deployment.startDate}, 
    // duration: {value: deployment.duration, displayed: deployment.duration} 
  };
}

export const deploymentStatusIcons = {
  "success": <CheckCircleOutline />,
  "failed": <ErrorOutline />,
  "running": <RotateRightOutlined />,
  "scheduled": <ScheduleOutlined />,
}

export const deploymentStatusColors = {
  "success": theme.palette.status.ok,
  "failed": theme.palette.status.fail,
  "running": theme.palette.status.progress,
  "scheduled": theme.palette.status.neutral,
}

export function DeploymentsTable({deployments}) {
  const history = useHistory();

  const onRowClicked = (id) => {
    history.push(`/deployments/${id}`);
  };

  return (
    <CustomTable columns={columns} rows={deployments.map(deployment => createTableRow(deployment))} handleRowClick={onRowClicked}/>
  );
}

export function SearchableDeploymentsTable({ deployments }) {
  const filter = (search) => {
    return (item) => {
      return item.iocName.toLowerCase().includes(search) 
      ||  item.version.sourceVersion.toLowerCase().includes(search)
      ||  item.host.host.toLowerCase().includes(search)
      ||  item.createdBy.toLowerCase().includes(search)
      ||  item.comment.toLowerCase().includes(search);
    }
  }

  const renderFilteredItems = (filteredDeployments) => {
    return (
        <DeploymentsTable deployments={filteredDeployments}/>
      );
  }

  return (
    <SearchBoxFilter items={deployments} filter={filter} render={renderFilteredItems}/>
  );
}