import React from 'react';
import { CustomTable } from '../common/table/CustomTable';
import { SearchBoxFilter } from "../common/SearchBoxFilter/SearchBoxFilter";
import { useHistory } from 'react-router-dom';
import { HostStatusIcon } from './HostIcons';


const columns = [
    { id: 'bulb', label: 'Status' },
    { id: 'host', label: 'Host' },
    { id: 'description', label: 'Description' },
    { id: 'network', label: 'Network' },
    { id: 'scope', label: 'Scope' },
    { id: 'user', label: 'User' },
    { id: 'deviceType', label: 'Device Type' },
    { id: 'status', label: 'Host Status' },
    // { id: 'isioc', label: 'Is IOC' },
    // { id: 'devicetype', label: 'Device Type' },
    // { id: 'description', label: 'Description' },
    // { id: 'createdby', label: 'Created By' },
    // { id: 'createdat', label: 'Created At'},
    // { id: 'vmowners', label: 'VM Owners'},
    // { id: 'ansiblevar', label: 'Ansible vars' },
];

export function createRow(hostContainer) {
    const host = hostContainer.csEntryHost;
    return {
        id: host.id,
        bulb: { value: host.status, displayed: <HostStatusIcon host={hostContainer} /> },
        host: { value: host.fqdn, displayed: host.fqdn },
        description: { value: host.description, displayed: host.description },
        network: { value: host.interfaces[0].network, displayed: host.interfaces[0].network },
        status: { value: hostContainer.status, displayed: hostContainer.status.toLowerCase() ?? "unknown" },
        deviceType: { value: host.device_type, displayed: host.device_type },
        user: { value: host.user, displayed: host.user },
        scope: { value: host.scope, displayed: host.scope },
        // isioc: { value: host.isioc, displayed: isIocIcons[host.isioc] },
        // devicetype: { value: host.devicetype, displayed: host.devicetype },
        // description: { value: host.description, displayed: host.description },
        // createdby: { value: host.createdby, displayed: host.createdby },
        // createdat: { value: host.createdat, displayed: host.createdat },
        // vmowners: { value: host.vmowners, displayed: formatToList(host.vmowners) },
        // ansiblevar: { value: host.ansiblevar, displayed: formatToList(host.ansiblevar) }
    };

}


export function HostsTable({ hosts }) {
    const history = useHistory();

    console.log(hosts);

    const onRowClicked = (id) => {
        history.push(`/hosts/${id}`);
    };

    return <CustomTable columns={columns} rows={hosts.map(host => createRow(host))} handleRowClick={onRowClicked} />;
}

export default function HostTable({ demoHosts }) {
    console.log(demoHosts);
    const filter = (search) => {
        search = search.toLowerCase();
        return (hostContainer) => {
            const host = hostContainer.csEntryHost;
            return host.interfaces[0].network?.toLowerCase().includes(search) ||
                host.fqdn?.toLowerCase().includes(search) ||
                host.device_type?.toLowerCase().includes(search) ||
                host.description?.toLowerCase().includes(search) ||
                host.user?.toLowerCase().includes(search) ||
                host.scope?.toLowerCase().includes(search);
                
        }
    }

    const renderFilteredHosts = (filteredHosts) => <HostsTable hosts={filteredHosts} />;

    return (
        <SearchBoxFilter items={demoHosts} filter={filter} render={renderFilteredHosts} />
    );
}