import { Container, Grid, Paper, Tab, Tabs } from "@material-ui/core";
import React, { useEffect, useState } from "react";
import { useCreateDeployment, useIOC } from "../../api/SwaggerApi";
import { IOCLiveStatus } from "../../components/IOC/IOCLiveStatus";
import { IOCConfiguration } from "../../components/IOC/IOCConfiguration";
import { useHistory } from "react-router-dom";

export function IOCDetailsView({ match }) {
  const id = parseInt(match.params.id);
  const [selectedTab, setSelectedTab] = useState("Configuration");
  const [firstTime, setFirstTime] = useState(true);
  const [ioc, getIOC] = useIOC(id);
  const [deployment, createDeployment] = useCreateDeployment();
  const history = useHistory();
  console.log(ioc);

  const handleTabChange = (event, tab) => {
    setSelectedTab(tab);
  };

  useEffect(() => {
    if (deployment) history.push(`/deployments/${deployment[0].id}`);
  }, [deployment, history]);

  useEffect(() => {
    if (firstTime && ioc && ioc.activeDeployment) {
      setSelectedTab("Live Status");
      setFirstTime(false);
    }
  }, [ioc, firstTime]);

  return (
      <Container style={{paddingBottom: "200px"}}>
        <Paper>
          <Grid container spacing={1}>
            <Grid item xs={12}>
              <Grid container justify="center">
                <Tabs
                  value={selectedTab}
                  onChange={handleTabChange}
                  indicatorColor="primary"
                  textColor="primary"
                >
                  {ioc && ioc.activeDeployment && <Tab label="Live Status" value="Live Status" />}
                  {ioc && <Tab label="Configuration" value="Configuration" />}
                </Tabs>
              </Grid>
            </Grid>
            <Grid item xs={12}>
              {selectedTab === "Live Status" && <IOCLiveStatus ioc={ioc} />}
              {selectedTab === "Configuration" && <IOCConfiguration ioc={ioc} getIOC={getIOC} deployment={deployment} createDeployment={createDeployment} />}
            </Grid>
          </Grid>
        </Paper>
      </Container>
  );
}