import { Container, Grid, Hidden, IconButton, Paper, Tab, Tabs, useTheme } from "@material-ui/core";
import { AddBox } from "@material-ui/icons";
import React, { useContext, useState } from "react"
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { SearchableIOCList } from "../../components/IOC/IOCList";
import { CreateIOC } from "../../components/IOC/CreateIOC";
import { SimpleModal } from "../../components/common/SimpleModal/SimpleModal";
import { SearchableIOCTable } from "../../components/IOC/IOCTable";
import { useCreateIOC, useIOCList, userContext } from "../../api/SwaggerApi";


export function IOCListView() {
  const [iocs] = useIOCList();
  const [iocFormOpen, setIOCFormOpen] = useState(false);
  const [selectedTab, setSelectedTab] = React.useState(0);
  const {user} = useContext(userContext);

  console.log("rendering IOCListView")

  const theme = useTheme();
  const title = "IOCs";
  const button = (
    <IconButton color="inherit" onClick={() => { setIOCFormOpen(true) }}>
      <AddBox style={{ fill: theme.palette.primary.contrastText }} />
    </IconButton>
  );
  useGlobalAppBar(title, button);

  const closeModal = () => {
    setIOCFormOpen(false);
  }

  function preFilter(tab, iocs) {
    console.log(iocs);
    if (tab === 0) {
      iocs = iocs.filter((ioc) => ioc.owner === user.loginName);
    }

    const abcIOCs = iocs.sort((a, b) => a.name.localeCompare(b.name));
    return abcIOCs;
  };

  const handleTabChange = (event, tab) => {
    setSelectedTab(tab);
  };


  let content = <></>;
  if (true) {
    const preFilteredIOCs = preFilter(selectedTab, iocs);
    content = (
      <>
        <Hidden smUp>
          <SearchableIOCList iocs={preFilteredIOCs} />
        </Hidden>
        <Hidden xsDown>
          <SearchableIOCTable iocs={preFilteredIOCs} />
        </Hidden>
      </>
    );
  }

  return (
    <Container>
      <Paper>
        <Grid container spacing={1}>
          <Grid item xs={12}>
            <Grid container justify="center">

              <Tabs
                value={selectedTab}
                onChange={handleTabChange}
                indicatorColor="primary"
                textColor="primary"
              >
                <Tab label="Your IOCs" />
                <Tab label="Explore IOCs" />
              </Tabs>
            </Grid>

          </Grid>
          <Grid item xs={12}>
            {content}
          </Grid>
          <SimpleModal open={iocFormOpen} setOpen={setIOCFormOpen}>
            <CreateIOC submitCallback={closeModal} hook={useCreateIOC} buttonText="Create"/>
          </SimpleModal>
        </Grid>
      </Paper>
    </Container>
  );
}

