import React, { useContext, useState} from 'react';
import { makeStyles } from '@material-ui/core/styles';
import {Paper, Container, Grid, FormControlLabel, Switch, Hidden } from '@material-ui/core';
import Tabs from '@material-ui/core/Tabs';
import Tab from '@material-ui/core/Tab';
import { SearchableDeploymentsTable } from "../../components/deployments/DeploymentsTable";
import { SearchableDeploymentsList } from "../../components/deployments/DeploymentsList";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { useDeploymentList, userContext } from '../../api/SwaggerApi';


const useStyles = makeStyles({
  root: {
    width: '100%'
  },
  formControl: {
    marginLeft: '5px',
    marginRight: '5px',
  }
});

export function DeploymentsView() {
  const classes = useStyles();
  const [deployments] = useDeploymentList();
  const [selectedTab, setSelectedTab] = useState(0);
  const [ownOnly, setOwnOnly] = useState(false);
  const {user} = useContext(userContext);

  console.log(deployments);

  useGlobalAppBar(
    "Deployments"
  );
  
  
  function performFilter(tab, own, deploymentList) {
    const prefiltered = own ? deploymentList.filter(deployment => deployment.createdBy === user.loginName) : deployments;
    if (tab === 0) {
      return prefiltered;
    }
    else if (tab === 1) {
      return prefiltered.filter(deployment => deployment.status === "running");
    }
    else if (tab === 2) {
      return prefiltered.filter(deployment => deployment.status !== "running" && deployment.status !== "scheduled");
    }
    else if (tab === 3) {
      return prefiltered.filter(deployment => deployment.status === "scheduled");
    }
  };

  const handleTabChange = (event, tab) => {
    setSelectedTab(tab);
  };

  const handleChangeOwn = (event) => {
    const own = event.target.checked;
    setOwnOnly(own);
  };

  const content = (
    <>
      <Hidden smUp>
        <SearchableDeploymentsList deployments={performFilter(selectedTab, ownOnly, deployments)}/>
      </Hidden>
      <Hidden xsDown>
        <SearchableDeploymentsTable deployments={performFilter(selectedTab, ownOnly, deployments)}/>
      </Hidden>
    </>
  );
  

  return (
      <Container className={classes.root}>
        <Paper>
          <Grid container spacing={1} justify="flex-start">
            <Grid item xs={12} md={10}>
              <Tabs
                value={selectedTab}
                onChange={handleTabChange}
                indicatorColor="primary"
                textColor="primary">
                <Tab label="All" />
                <Tab label="Running" />
                <Tab label="Finished" />
                <Tab label="Scheduled" />
              </Tabs>
            </Grid>
            <Grid item xs={8} md={2}>
              <FormControlLabel className={classes.formControl}
                control={<Switch checked={ownOnly} onChange={handleChangeOwn} />}
                label="My deployments"
              />
            </Grid>
            <Grid item xs={12} md={12}>
              {content}
            </Grid>
          </Grid>
        </Paper>
      </Container>
  );
}
