import React from 'react';
import {
    Paper,
    Link,
    Container,
    Hidden
} from '@material-ui/core';
import { useHost, useHostIOCList } from '../../api/SwaggerApi';
import { useGlobalAppBar } from '../../components/navigation/GlobalAppBar/GlobalAppBar';
import { HostBadge } from '../../components/host/HostBadge';
import { SimpleAccordion } from '../../components/common/Accordion/SimpleAccordion';
import { SearchableIOCList } from '../../components/IOC/IOCList';
import { SearchableIOCTable } from '../../components/IOC/IOCTable';
import { KeyValueTable } from '../../components/common/KeyValueTable/KeyValueTable';

export function HostDetailsView({ match }) {
    const id = parseInt(match.params.id);
    useGlobalAppBar("Host Details");
    const [host] = useHost(id);
    const [iocs] = useHostIOCList(id);
    console.log({ ...iocs });
    console.log({ ...host });

    const renderHost = { ...host?.csEntryHost };
    delete renderHost.id;
    renderHost.interfaces = <pre>{JSON.stringify(host?.csEntryHost?.interfaces, null, 2)}</pre>;
    renderHost.ansible_vars = <pre>{JSON.stringify(host?.csEntryHost?.ansible_vars, null, 2)}</pre>
    renderHost.ansible_groups = <pre>{JSON.stringify(host?.csEntryHost?.ansible_groups, null, 2)}</pre>

    renderHost["Open in CSEntry"] = <Link href={`https://csentry.esss.lu.se/network/hosts/view/${host?.csEntryHost.name}`} target="_blank" rel="noreferrer">{`https://csentry.esss.lu.se/network/hosts/view/${host?.csEntryHost?.name}`}</Link>

    return (
        <Container>
            <Paper>
                {host && <HostBadge host={host} />}
                <SimpleAccordion summary="Deployed IOCs" defaultExpanded>
                    <Hidden smUp>
                        <SearchableIOCList iocs={iocs?.deployed ?? []} />
                    </Hidden>
                    <Hidden xsDown>
                        <SearchableIOCTable iocs={iocs?.deployed ?? []} />
                    </Hidden>
                </SimpleAccordion>
                <SimpleAccordion summary="CSEntry Configuration" defaultExpanded>
                    {host && <KeyValueTable obj={renderHost} variant="table" />}
                </SimpleAccordion>
            </Paper>
        </Container>
    );
}